
/**
 * Klasse zur Beschreibung eines interaktiven Textfeldes
 * 
 * @author Klaus Reinold
 * @version 1.0
 */
public class Textfeld extends Ereignisbehandlung
{
    /** x-Position */
    int x;
    /** y-Position */
    int y;
    /** Breite des Textfelds */
    int breite;
    /** Inhalt des Textfelds */
    String inhalt;
    /** Gibt an, ob das Textfeld gerade aktiv ist. */
    boolean istAngeklickt;
    /** Das Rechteck als Hintergrund */
    Rechteck rahmen;
    /** Das darstellende Textfeld */
    Text text;

    /**
     * Konstruktor des Textfeldes
     */
    Textfeld()
    {
        x = 10;
        y = 10;
        breite = 300;
        inhalt = "Klick mich an und schreib was rein.";
        istAngeklickt = false;

        rahmen = new Rechteck();
        rahmen.GrößeSetzen(300, 20);
        rahmen.PositionSetzen(x, y);
        rahmen.FarbeSetzen("weiß");

        text = new Text();
        text.PositionSetzen(x + 5, y + 12);
        text.TextSetzen(inhalt);

    }

    /**
     * Ereignisroutine des Mausklicks
     * @param xKlick x-Position des Mausklicks
     * @param yKlick y-Position des Mausklicks
     * @param anzahl Anzahl der Klicks
     */
    @Override void MausGeklickt(int xKlick, int yKlick, int anzahl)
    {
        if(xKlick >= x && xKlick <=x + breite && yKlick > y && yKlick < y + 20)
        {
            istAngeklickt = true;
        }
        else
        {
            istAngeklickt = false;
        }
    }

    /**
     * Ereignisroutine des Tastendrucks
     * @param c gedrückte Taste
     */
    @Override void TasteGedrückt(char c)
    {
        if(istAngeklickt)
        {
            if(inhalt == "Klick mich an und schreib was rein.")
            {
                inhalt = "" + c;
            }
            else
            {
                inhalt = inhalt + c;
            }
            text.TextSetzen(inhalt);
        }
    }

    /**
     * Position des Textfeldes setzen
     * @param xNeu neue x-Koordinate
     * @param yNeu neue y-Koordinate
     */
    void PositionSetzen(int xNeu, int yNeu)
    {
        x = xNeu;
        y = yNeu;
        rahmen.PositionSetzen(x, y);
        text.PositionSetzen(x + 5, y + 12);
    }
    
    /**
     * Methode zum Setzen des Textes
     * @param tNeu neuer Text
     */
    void TextSetzen(String tNeu)
    {
        inhalt = tNeu;
        text.TextSetzen(inhalt);
    }
}
