
/**
 * Beschreibt einen Heizkörper
 * 
 * @author Albert Wiedemann
 * @version 1.0
 */
class Heizkoerper
{
    /** Name der Hauskomponente */
    String name;
    /** Zustand des Heizkörpers */
    boolean an;
    /** Automatikbetrieb */
    boolean automatik;
    /** Wert des Thermometers */
    int temperatur;
    /** Darstellungssymbol */
    HeizkoerperSymbol symbol;

    /**
     * Legt den Namen und das Darstellungssymbol fest
     * @param namensZusatz individualler Namensteil der Komponente
     * @param sy Darstellungssymbol
     * @param t Thermometer
     */
    Heizkoerper(String namensZusatz, HeizkoerperSymbol sy, Thermometer t)
    {
        name = "Heizkörper " + namensZusatz;
        temperatur = 0;
        an = true;
        automatik = true;
        symbol = sy;
        symbol.ÄnderungMelden(an);
        t.BeobachterRegistrieren(this);
    }

    /**
     * Wird vom Thermometer bei einer neuen Temperatur aufgerufen
     * @param wert die neue Temperatur
     */
    void WertänderungMelden(int wert)
    {
        temperatur = wert;
        if (automatik)
        {
            an = temperatur < 22;
            symbol.ÄnderungMelden(an);
        }
    }
    
    /**
     * Meldet den Zustand der Komponente
     * @return Zustand als Zeichenkette
     */
    String ZustandGeben()
    {
        return an ? "ein" : "aus";
    }
    
    /**
     * Schaltet die Komponente dauerhaft ein
     */
    void Einschalten()
    {
        an = true;
        automatik = false;
        symbol.ÄnderungMelden(an);
    }
    
    /**
     * Schaltet die Komponente dauerhaft aus
     */
    void Ausschalten()
    {
        an = false;
        automatik = false;
        symbol.ÄnderungMelden(an);
    }
    
    /**
     * Schaltet die Komponente auf Automatikbetrieb
     */
    void AutomatikAktivieren()
    {
        an = temperatur < 22;
        automatik = true;
        symbol.ÄnderungMelden(an);
    }
}
