
/**
 * Beschreibt eine Lampe
 * 
 * @author Albert Wiedemann
 * @version 1.0
 */
class Lampe
{
    /** Name der Hauskomponente */
    String name;
    /** Zustand der Lampe */
    boolean an;
    /** Automatikbetrieb */
    boolean automatik;
    /** Wert des Bewegungsmelders */
    boolean bewegung;
    /** Wert des Sonnensensors */
    int helligkeit;
    /** Darstellungssymbol */
    LampenSymbol symbol;

    /**
     * Legt den Namen und das Darstellungssymbol fest
     * @param namensZusatz individualler Namensteil der Komponente
     * @param sy Darstellungssymbol
     * @param b Bewegungsmelder
     * @param s Sonnensensor
     */
    Lampe(String namensZusatz, LampenSymbol sy, Bewegungsmelder b, Sonnensensor s)
    {
        name = "Lampe " + namensZusatz;
        bewegung = false;
        helligkeit = 0;
        an = false;
        automatik = true;
        symbol = sy;
        symbol.ÄnderungMelden(an);
        s.BeobachterRegistrieren(this);
        b.BeobachterRegistrieren(this);
    }

    /**
     * Wird von Sonnensensor bei einem neuen Helligkeitswert aufgerufen
     * @param wert der neue Helligkeitswert
     */
    void WertänderungMeldenSonnenSensor(int wert)
    {
        helligkeit = wert;
        if (automatik)
        {
            an = bewegung && (helligkeit < 30);
            symbol.ÄnderungMelden(an);
        }
    }

    /**
     * Wird von Bewegungsmelder bei einem neuen Bewegungszustand aufgerufen
     * @param wert der neue Bewegungszustand
     */
    void WertänderungMeldenBewegungsmelder(boolean wert)
    {
        bewegung = wert;
        if (automatik)
        {
            an = bewegung && (helligkeit < 30);
            symbol.ÄnderungMelden(an);
        }
    }
    
    /**
     * Meldet den Zustand der Komponente
     * @return Zustand als Zeichenkette
     */
    String ZustandGeben()
    {
        return an ? "ein" : "aus";
    }
    
    /**
     * Schaltet die Komponente dauerhaft ein
     */
    void Einschalten()
    {
        an = true;
        automatik = false;
        symbol.ÄnderungMelden(an);
    }
    
    /**
     * Schaltet die Komponente dauerhaft aus
     */
    void Ausschalten()
    {
        an = false;
        automatik = false;
        symbol.ÄnderungMelden(an);
    }
    
    /**
     * Schaltet die Komponente auf Automatikbetrieb
     */
    void AutomatikAktivieren()
    {
        an = bewegung && (helligkeit < 30);
        automatik = true;
        symbol.ÄnderungMelden(an);
    }
}
